@@ -242,8 +242,12 @@ int main(int argc, char *argv[])
   delay_us(2500000);
 #endif
 
-#ifndef MAEMO
-  gpsp_plat_init();
+#ifndef PC_BUILD
+#ifdef MAEMO
+ gpsp_plat_init(&argc, &argv);
+#else
+ gpsp_plat_init();
+#endif
 #endif
   load_config_file();
 
@@ -820,7 +824,7 @@ void synchronize()
   }
   else if (synchronize_flag)
   {
-#if defined(MAEMO)
+#if defined(PND_BUILD)
     fb_wait_vsync();
 #elif !defined(GP2X_BUILD) // sleeping on GP2X is a bad idea
     delay_us((u64)virtual_frame_count * 50000 / 3 - new_ticks + 2);
